@@ -5,10 +5,10 @@ use warnings;
 
 use File::Spec ();
 use Mojo::Base -base;
-use Mojo::Loader;
+use Mojo::Loader qw(data_section);
 use Text::Xslate ();
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 $VERSION = eval $VERSION;
 
 has 'xslate';
@@ -28,7 +28,7 @@ sub _init {
 
     if ($app) {
         $cache_dir = $app->home->rel_dir('tmp/compiled_templates');
-        push @path, Mojo::Loader->new->data(
+        push @path, data_section(
             $app->renderer->classes->[0],
         );
     }
@@ -167,7 +167,7 @@ L<http://search.cpan.org/dist/MojoX-Renderer-Xslate/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2013 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2010-2015 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
